```
Image: ChrisRuvolo, Public domain, via Wikimedia Commons
```
tl.load and tl.store do in Triton: read/write tensors from/to GPU global memory
`tl.load` reads tensors from GPU memory; `tl.store` writes tensors to GPU memory
tl.dot does in Triton: block-level matrix multiply using tensor cores
tl.dot performs block-level matrix multiplication using tensor cores in Triton
to write a fused softmax kernel in Triton: load row, compute max, subtract, exp, sum, divide
Softmax function converts real numbers to a probability distribution
a Triton @triton.jit decorator does: compiles a Python function into a GPU kernel
@triton.jit decorator compiles Python function into a GPU kernel
a Triton kernel is
Can your phone run faster with a different brain?
tl.arange(0, BLOCK_SIZE) creates: a range of indices within the current block
Python's annual release cycle
Swipe through 100 ML concepts daily
Open Pocket Polymath